@@ -5,10 +5,10 @@ use 5.006;
 use strict;
 
 our $NAME       = __PACKAGE__;     # name of entire application
-our $VERSION    = '0.3.9.15';      # version of entire app
+our $VERSION    = '0.3.9.16';      # version of entire app
 our $PATCHLEVEL;                   # has just stable versions
 our $STANDALONE = '';              # starter flag for moveable installations
-our $BENCHMARK;                    #
+our $BENCHMARK;                    # flag for benchmark loggings
 our @ISA        = 'Wx::App';       # $NAME is a wx application
 
 # Configuration Phase
