@@ -1,9 +1,11 @@
 package Kephra::App::EditPanel;
-$VERSION = '0.10';
+use strict;
+use warnings;
+
+our $VERSION = '0.10';
 
 # visual settings of the Edit Panel
 
-use strict;
 use Wx qw(
 		wxDEFAULT wxNORMAL wxLIGHT wxBOLD wxSLANT wxITALIC
 		wxSTC_CACHE_PAGE
@@ -289,4 +291,4 @@ sub change_font {
 #$ep->StyleSetBackground (wxSTC_STYLE_CONTROLCHAR, Wx::Colour->new(0xff, 0xff, 0xff));
 #$ep->SetScrollWidth($Kephra::config{'editpanel'}{'scroll_width'}); #defaultbreite
 #$ep->CallTipShow(3,"testtooltip\n next line"); #tips
-#$ep->SetSelectionMode(wxSTC_SEL_RECTANGLE); #rect selection
\ No newline at end of file
+#$ep->SetSelectionMode(wxSTC_SEL_RECTANGLE); #rect selection
