@@ -1,9 +1,11 @@
 package Kephra::Config::Interface;
-$VERSION = '0.03';
+use strict;
+use warnings;
+
+our $VERSION = '0.03';
  
 # handling config files under config/interface and config/localisation
 
-use strict;
 
 sub load {
 	my $conf      = $Kephra::config{app};
@@ -84,4 +86,4 @@ sub set_documentation_lang {
 	}
 }
 
-1;
\ No newline at end of file
+1;
