@@ -1,7 +1,9 @@
 package Kephra::Dialog::Notify;
-$VERSION = '0.02';
-
 use strict;
+use warnings;
+
+our $VERSION = '0.02';
+
 use Wx qw(
 		wxVERTICAL wxHORIZONTAL             wxRIGHT wxLEFT wxGROW wxTOP wxALL
 		wxLEFT wxCENTER wxRIGHT wxBOTTOM    wxWHITE
@@ -73,4 +75,4 @@ sub quit_dialog {
 	$dialog->Destroy();
 }
 
-1;
\ No newline at end of file
+1;
