@@ -1,6 +1,8 @@
 package Kephra::Document::Property;
-$VERSION = '0.01';
-
 use strict;
+use warnings;
 
-1;
\ No newline at end of file
+our $VERSION = '0.01';
+
+
+1;
