@@ -1,7 +1,9 @@
 package Kephra::Edit::Convert;
-$VERSION = '0.08';
-
 use strict;
+use warnings;
+
+our $VERSION = '0.08';
+
 use Wx qw(wxSTC_CMD_UPPERCASE wxSTC_CMD_LOWERCASE wxSTC_CMD_WORDRIGHT);
 
 # Convert
