@@ -1,7 +1,8 @@
 package Kephra::File::History;
-$VERSION = '0.03';
-
 use strict;
+use warnings;
+
+our $VERSION = '0.03';
 
 # internal Module API
 sub _config{ $Kephra::config{file}{history} }
@@ -51,4 +52,4 @@ sub add {
 sub delete_gone {
  my @exist = grep { -e $_ } @{ _get() };
 	_set(\@exist);
-}
\ No newline at end of file
+}
